import { DesignSystem } from '@microsoft/fast-foundation';
/**
 * DesignSystemModule.
 * @public
 */
export interface DesignSystemModule {
    provideDesignSystem(element?: HTMLElement, prefix?: string): DesignSystem | Pick<DesignSystem, 'register'>;
    [key: string]: any;
}
/**
 * DesignSystemResource.
 * @public
 */
export type DesignSystemResource<T = DesignSystemModule> = Promise<T>;
/**
 * assureDesignSystem.
 *
 * @remarks
 * Webpack caching strategies can backfill missing modules with placeholders in an attempt to prevent errors. In the case
 * of offline remotes, we rely on the error to fall back to local versions. This utility assures we have a design system.
 *
 * @example
 * ```ts
 * async function zeroDesignSystemImport(): Promise<DesignSystemModule> {
 *   let module: DesignSystemModule;
 *   let type: ResourceType = ResourceType.remote;
 *   try {
 *     module = await import('foundationZero/ZeroDesignSystem');
 *     return assureDesignSystem(module);
 *   } catch (e) {
 *     logger.info(
 *       `Please note remoteEntry.js load errors are expected if module federated dependencies are offline. Falling back to locally bundled versions.`,
 *     );
 *     type = ResourceType.local;
 *     module = await import('@genesislcap/foundation-zero');
 *     return assureDesignSystem(module);
 *   } finally {
 *     logger.debug(`Using '${type}' version of foundation-zero`);
 *   }
 * }
 * ```
 *
 * @example You should also instruct webpack to use strict module handling.
 * ```ts
 * output: {
 *   strictModuleErrorHandling: true,
 *   strictModuleExceptionHandling: true,
 * }
 * ```
 *
 * @public
 */
export declare function assureDesignSystem(module: DesignSystemModule): DesignSystemModule;
//# sourceMappingURL=design-system.d.ts.map